<?php

namespace eindwerk\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Container\ContainerInterface;


class ClientsController
{
    protected $container;
    protected $response;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function getAllClients(Request $request, Response $response): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT id, name, btw_nr, address
            FROM client
        ');
        $res = $query->execute();
        $data = [];
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function getClient(Request $request, Response $response, array $args): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT C.id, C.name, C.btw_nr, C.address
            FROM client C
            WHERE C.id = :id
        ');
        $query->bindValue(':id', $args['id']);
        $res = $query->execute();

        if ($res) {
            $data = [];
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data, $row);
            }
            $response->getBody()->write(json_encode($data));
            return $response->withHeader('Content-Type', 'application/json');
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
    }

    public function saveClient(Request $request, Response $response, array $args): Response
    {
        $parsedBody = $request->getParsedBody();

        if (!isset($parsedBody['name']) || !isset($parsedBody['btw_nr']) || !isset($parsedBody['address'])) {
            $response->getBody()->write('No name or description given.');
            return $response->withStatus(400);
        }

        $bId = isset($parsedBody['id']) ? strval($parsedBody['id']) : null;
        $aId = isset($args['id']) ? $args['id'] : null;
        $clientId = $bId ?: $aId;

        $db = $this->container->get('db');
        if (!$clientId) {
            $query = $db->prepare('
                INSERT INTO client (name, btw_nr, address)
                values (:name, :btw_nr, :address)
            ');
        } else {
            $query = $db->prepare('
                UPDATE client
                SET name = :name, btw_nr = :btw_nr, address = :address
                WHERE id = :id
            ');
            $query->bindValue(':id', $clientId);
        }
        $query->bindValue(':name', $parsedBody['name']);
        $query->bindValue(':btw_nr', $parsedBody['btw_nr']);
        $query->bindValue(':address', $parsedBody['address']);

        if ($query->execute()) {
            $response->getBody()->write($clientId ?: strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }
}
