<?php

namespace eindwerk\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Container\ContainerInterface;


class InvoiceController
{
    protected $container;
    protected $response;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function getAllInvoices(Request $request, Response $response): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT id, date, due_date, client_id, project_id
            FROM invoice
        ');
        $res = $query->execute();
        $data = [];
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function updateInvoice(Request $request, Response $response, array $args): Response
    {
        $parsedBody = $request->getParsedBody();
        $hasBeenMade = false;
        $db = $this->container->get('db');

        $getQuery = $db->prepare('
            SELECT project_id
            FROM invoice
            WHERE project_id = :project_id 
        ');
        $getQuery->bindValue(':project_id', $parsedBody['project_id']);

        $data = [];
        $res = $getQuery->execute();
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        foreach ($data as $d) {
            if ($d = $parsedBody['project_id']) {
                $hasBeenMade = true;
            }
        }

        if (!$hasBeenMade) {
            $query = $db->prepare('
                INSERT INTO invoice (date, due_date, client_id, project_id)
                values (:date, :due_date, :client_id, :project_id)
            ');
        } else {
            $query = $db->prepare('
                UPDATE invoice
                SET date = :date, due_date = :due_date, client_id = :client_id, project_id = :project_id
                WHERE project_id = :project_id
            ');
        }
        $query->bindValue(':date', $parsedBody['date']);
        $query->bindValue(':due_date', $parsedBody['due_date']);
        $query->bindValue(':client_id', $parsedBody['client_id']);
        $query->bindValue(':project_id', $parsedBody['project_id']);

        if ($query->execute()) {
            $response->getBody()->write($parsedBody['project_id'] ?: strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }
}
