<?php

namespace eindwerk\Controller;

use eindwerk\Entity\Task;
use eindwerk\Entity\State;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Container\ContainerInterface;


class ProjectsController
{
    protected $container;
    protected $response;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }

    public function getAllProjects(Request $request, Response $response): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT id, name, description
            FROM project
        ');
        $res = $query->execute();
        $data = [];
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function getUserTasks(Request $request, Response $response, array $args): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT name, description, project_id
            FROM task
            WHERE assignee_id = :id
        ');

        $query->bindValue(':id', $args['id']);

        $res = $query->execute();
        $data = [];
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    function getProjects(Request $request, Response $response, array $args)
    {
        $user = $request->getAttribute('user');
        $data = $user->getProjects();
        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    function getTasks(Request $request, Response $response, array $args)
    {
        $task = new Task($this->container);
        $data = $task->getTasks();
        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function saveTask(Request $request, Response $response, array $args)
    {
        $db = $this->container->get('db');
        $query = $db->prepare('UPDATE task SET name = :name, description = :description, assignee_id = :userId, time = :time WHERE id = :id');

        $query->bindValue(':name', $_POST['name']);
        $query->bindValue(':description', $_POST['description']);
        $query->bindValue(':id', $_POST['id']);
        if ($_POST['userId'] != 'null' and $_POST['userId'] != 'undefined') {
            $userId = $_POST['userId'];
        } else {
            $userId = NULL;
        }
        $query->bindValue(':userId', $userId);
        if ($_POST['time'] != 'null') {
            $cost = $_POST['time'];
        } else {
            $cost = 0;
        }
        $query->bindValue(':time', $cost);

        if ($query->execute()) {
            $response->getBody()->write(strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    // public function assignUserToCard(Request $request, Response $response, array $args)
    // {
    //     $db = $this->container->get('db');
    //     $query = $db->prepare('UPDATE task SET asignee_id = :userid WHERE id = :id');
    //
    //     $query->bindValue(':userid', $_POST['userid']);
    //     $query->bindValue(':id', $_POST['id']);
    //
    //     if ($query->execute()) {
    //         $response->getBody()->write(strval($db->lastInsertRowID()));
    //     } else {
    //         $response->getBody()->write($db->lastErrorMsg());
    //         return $response->withStatus(403);
    //     }
    //     return $response;
    // }

    function getStates(Request $request, Response $response, array $args)
    {
        $task = new Task($this->container);
        $data = $task->getStates();
        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    function getMergeStates(Request $request, Response $response, array $args)
    {
        $task = new Task($this->container);
        $results = $task->getStates();

        $db = $this->container->get('db');
        $query = $db->prepare('
        SELECT T.name, T.description, T.state_id, T.assignee_id, E.user_name, T.id, T.row, T.time
        FROM task T
        JOIN project P on T.project_id = P.id
        LEFT JOIN employee E on T.assignee_id = E.id
        WHERE T.project_id = :id
		ORDER BY row
        ');

        $query->bindValue(':id', $_GET['project_id']);

        $res = $query->execute();
        $data = [];
        while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
            array_push($data, $row);
        }

        $tasks_results = $data;

        foreach ($results as $value) {
            $value["tasks"] = [];
            $results[$value["id"] - 1] = $value;
        }

        foreach ($tasks_results as $tas) {
            $results[$tas['state_id'] - 1]['tasks'][] = $tas;
        }

        $response->getBody()->write(json_encode($results));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function getProject(Request $request, Response $response, array $args): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT P.id, P.name, P.description, P.team_id, P.city, P.country, P.cost_per_hour, T.name as team_name, P.client_id, C.name as client_name, C.btw_nr, C.address
            FROM project P
            LEFT JOIN team T
            ON P.team_id = T.id
            LEFT JOIN client C
            ON P.client_id = C.id
            WHERE P.id = :id
        ');
        $query->bindValue(':id', $args['id']);
        $res = $query->execute();

        if ($res) {
            $data = [];
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data, $row);
            }
            $response->getBody()->write(json_encode($data));
            return $response->withHeader('Content-Type', 'application/json');
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
    }

    public function saveProject(Request $request, Response $response, array $args): Response
    {
        $parsedBody = $request->getParsedBody();

        if (!isset($parsedBody['name']) || !isset($parsedBody['description'])) {
            $response->getBody()->write('No name or description given.');
            return $response->withStatus(400);
        }

        $bId = isset($parsedBody['id']) ? strval($parsedBody['id']) : null;
        $aId = isset($args['id']) ? $args['id'] : null;
        $projectId = $bId ?: $aId;

        $db = $this->container->get('db');
        if (!$projectId) {
            $query = $db->prepare('
                INSERT INTO project (name, description, cost_per_hour, client_id, team_id)
                values (:name, :description, :cost_per_hour, :client_id, :team_id)
            ');
        } else {
            $query = $db->prepare('
                UPDATE project
                SET name = :name, description = :description, cost_per_hour = :cost_per_hour
                WHERE id = :id
            ');
            $query->bindValue(':id', $projectId);
        }
        $query->bindValue(':name', $parsedBody['name']);
        $query->bindValue(':description', $parsedBody['description']);
        if ($parsedBody['cost_per_hour'] != NULL) {
            $cost = $parsedBody['cost_per_hour'];
        } else {
            $cost = 0;
        }
        $query->bindValue(':cost_per_hour', $cost);
        $query->bindValue(':client_id', $parsedBody['client_id']);
        $query->bindValue(':team_id', $parsedBody['team_id']);

        if ($query->execute()) {
            $response->getBody()->write($projectId ?: strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    function newTask(Request $request, Response $response, array $args)
    {
        $db = $this->container->get('db');

        $query = $db->prepare('INSERT INTO task (state_id, user_story_id, project_id, assignee_id, delegee_id, name, description, time) values (:state,1,:project_id,NULL,1,"Title", "Add a description", 0)'); // add row & column

        $query->bindValue(':state', $_POST['state_id']);
        $query->bindValue(':project_id', $_POST['project_id']);

        if ($query->execute()) {
            $response->getBody()->write(strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    public function BeginTaskUpdate(Request $request, Response $response, array $args) // just testing
    {
        $db = $this->container->get('db');
        $query = $db->prepare('UPDATE task SET row = row + 1 WHERE state_id = :state AND row >= :previousRow');

        $query->bindValue(':previousRow', $_POST['preRow']);
        $query->bindValue(':state', $_POST['stateValue']);

        if ($query->execute()) {
            $response->getBody()->write(strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    public function EndTaskUpdate(Request $request, Response $response, array $args) // just testing
    {
        $db = $this->container->get('db');
        $query = $db->prepare('UPDATE task SET state_id = :state, row = :row WHERE id = :id');

        $query->bindValue(':state', $_POST['stateValue']);
        $query->bindValue(':row', $_POST['rowValue']);
        $query->bindValue(':id', $_POST['id']);

        if ($query->execute()) {
            $response->getBody()->write(strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    public function deleteTask(Request $request, Response $response, array $args) // just testing
    {
        $db = $this->container->get('db');
        $query = $db->prepare('DELETE FROM task WHERE id = :id');

        $query->bindValue(':id', $_POST['task_id']);

        if ($query->execute()) {
            $response->getBody()->write(strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }
}
