<?php

namespace eindwerk\Controller;

use eindwerk\Entity\Team;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Container\ContainerInterface;


class TeamsController
{
    protected $container;
    protected $response;

    public function __construct(ContainerInterface $container)
    {
        $this->container = $container;
    }


    function getAllTeams(Request $request, Response $response, array $args)
    {
        $task = new Team($this->container);
        $data = $task->getAllTeams();
        $response->getBody()->write(json_encode($data));
        return $response->withHeader('Content-Type', 'application/json');
    }

    public function getTeam(Request $request, Response $response, array $args): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
            SELECT T.id, T.name, T.description
            FROM team T
            WHERE T.id = :id
        ');
        $query->bindValue(':id', $args['id']);
        $res = $query->execute();

        if ($res) {
            $data = [];
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data, $row);
            }
        }

        $query = $db->prepare('
        SELECT TM.team_id, TM.employee_id, E.user_name
        FROM team_member TM
        LEFT JOIN employee E
        ON TM.employee_id = E.id
        WHERE TM.team_id = :id
        ORDER BY user_name asc
        ');

        $query->bindValue(':id', $args['id']);
        $data[0]["member"] = [];
        $res = $query->execute();
        if ($res) {
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data[0]["member"], $row);
            }
            $response->getBody()->write(json_encode($data));
            return $response->withHeader('Content-Type', 'application/json');
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
    }

    public function saveTeam(Request $request, Response $response, array $args): Response
    {
        $parsedBody = $request->getParsedBody();

        if (!isset($parsedBody['name'])) {
            $response->getBody()->write('No name or description given.');
            return $response->withStatus(400);
        }

        $bId = isset($parsedBody['id']) ? strval($parsedBody['id']) : null;
        $aId = isset($args['id']) ? $args['id'] : null;
        $teamId = $bId ?: $aId;

        $db = $this->container->get('db');
        if (!$teamId) {
            $query = $db->prepare('
                INSERT INTO team (name, description)
                values (:name, :description)
            ');
        } else {
            $teamQuery = $db->prepare('
                DELETE FROM team_member 
                WHERE team_id = :id
            ');
            $teamQuery->bindValue(':id', $teamId);
            $teamQuery->execute();
            foreach ($parsedBody['member'] as $member) {
                $InsertQuery = $db->prepare('
                INSERT INTO team_member (employee_id, team_id)
                values (:employee_id, :team_id)
            ');
                $InsertQuery->bindValue(':employee_id', isset($member["employee_id"]) ? $member["employee_id"] : $member["id"]);
                $InsertQuery->bindValue(':team_id', $teamId);
                $InsertQuery->execute();
            }

            $query = $db->prepare('
                UPDATE team
                SET name = :name, description = :description
                WHERE id = :id
            ');
        }



        $query->bindValue(':name', $parsedBody['name']);
        $query->bindValue(':id', $teamId);
        $query->bindValue(':description', $parsedBody['description']);

        if ($query->execute()) {
            $response->getBody()->write($teamId ?: strval($db->lastInsertRowID()));
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
        return $response;
    }

    public function getTeamMembers(Request $request, Response $response, array $args): Response
    {
        $db = $this->container->get('db');
        $query = $db->prepare('
        SELECT T.id, T.name, TM.team_id, TM.employee_id, E.user_name
        FROM team T
        LEFT JOIN team_member TM
        ON T.id = TM.team_id
        LEFT JOIN employee E
        ON TM.employee_id = E.id
        ORDER BY name asc
        ');
        $res = $query->execute();

        if ($res) {
            $data = [];
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data, $row);
            }
            $response->getBody()->write(json_encode($data));
            return $response->withHeader('Content-Type', 'application/json');
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
    }

    public function saveTeamMembers(Request $request, Response $response, array $args): Response
    {
        $parsedBody = $request->getParsedBody();

        $db = $this->container->get('db');
        $query = $db->prepare('
        REPLACE INTO team_member(employee_id, price_id, team_id, position_id)
        VALUES(:employee_id, 1, :team_id, 1)
        ');

        $query->bindValue(':employee_id', $parsedBody['employee_id']);
        $query->bindValue(':team_id', $parsedBody['team_id']);

        $res = $query->execute();

        if ($res) {
            $data = [];
            while ($row = $res->fetchArray(SQLITE3_ASSOC)) {
                array_push($data, $row);
            }
            $response->getBody()->write(json_encode($data));
            return $response->withHeader('Content-Type', 'application/json');
        } else {
            $response->getBody()->write($db->lastErrorMsg());
            return $response->withStatus(403);
        }
    }
}
