<?php

namespace eindwerk\Middleware;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;
use Psr\Http\Server\RequestHandlerInterface as RequestHandler;
use Slim\Routing\RouteContext;

// https://www.slimframework.com/docs/v4/cookbook/enable-cors.html

class CorsMiddleware
{
    public function __invoke(Request $request, RequestHandler $handler): Response
    {
        $routeContext = RouteContext::fromRequest($request);
        $routingResults = $routeContext->getRoutingResults();
        $methods = $routingResults->getAllowedMethods();
        $requestHeaders = $request->getHeaderLine('Access-Control-Request-Headers');
        $origin = $request->getHeaderLine('HTTP_ORIGIN') ?: $request->getHeaderLine('HTTP_REFERER');

        $response = $handler->handle($request);

        $urlList = $_ENV['FRONTEND_URL'] ?: 'http://localhost:3000';
        $urlArr = explode(',', $urlList);
        $allowedOrigin = $urlArr[array_search($origin, $urlArr, true)];

        $response = $response->withHeader('Access-Control-Allow-Origin', $allowedOrigin);
        $response = $response->withHeader('Access-Control-Allow-Methods', implode(',', $methods));
        $response = $response->withHeader('Access-Control-Allow-Headers', $requestHeaders);
        $response = $response->withHeader('Access-Control-Max-Age', '86400'); 

        // Optional: Allow Ajax CORS requests with Authorization header
        $response = $response->withHeader('Access-Control-Allow-Credentials', 'true');

        return $response;

    }
}
