<?php

require __DIR__ . '/vendor/autoload.php';

$dbfile = getenv("DB_FILE") ?: "db2.sqlite";
$db = new SQLite3('../../backend/db/' . $dbfile);

$faker = Faker\Factory::create();
$faker->addProvider(new Faker\Provider\nl_BE\Payment($faker));
$faker->addProvider(new Faker\Provider\en_US\Company($faker));
$faker->addProvider(new Faker\Provider\en_US\Person($faker));

for ($i = 0; $i < 4; $i++) {
   $state = $db->prepare("
      INSERT INTO state (name)
      values (:name)
   ");
   $state->bindValue(':name', $faker->word);
   $state->execute();
}

for ($i = 1; $i < 15; $i++) {

   $user_name = $faker->userName;

   $user = $db->prepare("
      INSERT INTO user (name, password)
      values (:name, :password)
   ");
   $user->bindValue(':name', $user_name);
   $user->bindValue(':password', password_hash($faker->password, CRYPT_SHA256));
   $user->execute();

   $client = $db->prepare("
      INSERT INTO client (name, btw_nr, address)
      values (:name, :btw_nr, :address)
   ");
   $client->bindValue(':name', $faker->name);
   $client->bindValue(':btw_nr', $faker->vat);
   $client->bindValue(':address', $faker->address);
   $client->execute();

   $grade = $db->prepare("
      INSERT INTO grade (title)
      values (:title)
   ");
   $grade->bindValue(':title', $faker->jobTitle);
   $grade->execute();

   $position = $db->prepare("
      INSERT INTO position (title)
      values (:title)
   ");
   $position->bindValue(':title', $faker->jobTitle);
   $position->execute();

   $price = $db->prepare("
      INSERT INTO price (rate)
      values (:rate)
   ");
   $price->bindValue(':rate', $faker->numberBetween($min = 10, $max = 9000));
   $price->execute();

   $employee = $db->prepare("
      INSERT INTO employee (user_name, first_name, last_name, grade_id, rate, email, address)
      values (:user_name, :first_name, :last_name, :grade_id, :rate, :email, :address)
   ");
   $employee->bindValue(':user_name', $user_name);
   $employee->bindValue(':first_name', $faker->firstName);
   $employee->bindValue(':last_name', $faker->lastName);
   $employee->bindValue(':grade_id', $i);
   $employee->bindValue(':rate', $faker->numberBetween($min = 10, $max = 9000));
   $employee->bindValue(':email', $faker->email);
   $employee->bindValue(':address', $faker->address);
   $employee->execute();

   $team = $db->prepare("
      INSERT INTO team (name)
      values (:name)
   ");
   $team->bindValue(':name', $faker->userName);
   $team->execute();

   $team_member = $db->prepare("
      INSERT INTO team_member (employee_id, price_id, team_id, position_id)
      values (:employee_id, :price_id, :team_id, :position_id)
   ");
   $team_member->bindValue(':employee_id', $i);
   $team_member->bindValue(':price_id', $i);
   $team_member->bindValue(':team_id', $i);
   $team_member->bindValue(':position_id', $i);
   $team_member->execute();

   $project = $db->prepare("
      INSERT INTO project (client_id, name, description, team_id)
      values (:client_id, :name, :description, :team_id)
   ");
   $project->bindValue(':client_id', $i);
   $project->bindValue(':name', $faker->word);
   $project->bindValue(':description', $faker->text);
   $project->bindValue(':team_id', $i);
   $project->execute();

   $user_story = $db->prepare("
      INSERT INTO user_story (project_id, title, description)
      values (:project_id, :title, :description)
   ");
   $user_story->bindValue(':project_id', $i);
   $user_story->bindValue(':title', $faker->word);
   $user_story->bindValue(':description', $faker->text);
   $user_story->execute();

   $task = $db->prepare("
      INSERT INTO task (state_id, user_story_id, project_id, assignee_id, name, description)
      values (:state_id, :user_story_id, :project_id, :assignee_id, :name, :description)
   ");
   $task->bindValue(':state_id', ($i % 4) + 1);
   $task->bindValue(':user_story_id', $i);
   $task->bindValue(':project_id', $i);
   $task->bindValue(':assignee_id', $i);
   $task->bindValue(':name', $faker->word);
   $task->bindValue(':description', $faker->text);
   $task->execute();


   // TODO
   // invoice
   // work
   // product
   // invoice-line
   // quotation

}
