require('dotenv').config();

export default {
  mode: 'universal',
  target: 'static',
  /*
   ** Headers of the page
   */
  head: {
    title: process.env.npm_package_name || '',
    meta: [
      { charset: 'utf-8' },
      { name: 'viewport', content: 'width=device-width, initial-scale=1' },
      {
        hid: 'description',
        name: 'description',
        content: process.env.DESCRIPTION || '',
      },
      {
        rel: 'preconnect',
        href: 'https://fonts.gstatic.com',
      },
      {
        rel: 'stylesheet',
        href:
          'https://fonts.googleapis.com/css2?family=Barlow:ital,wght@0,400;0,600;0,700;1,400;1,600&family=Roboto:ital,wght@0,100;0,300;0,400;0,500;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap',
      },
    ],
    link: [{ rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' }],
  },
  /*
   ** Customize the progress-bar color
   */
  loading: { color: '#fff' },
  /*
   ** Global CSS
   */
  css: ['~/assets/sass/main'],
  /*
   ** Plugins to load before mounting the App
   */
  plugins: ['~/plugins/vue-formulate'],
  /*
   ** Nuxt.js dev-modules
   */
  buildModules: [
    // Doc: https://github.com/nuxt-community/eslint-module
    '@nuxtjs/eslint-module',
  ],
  /*
   ** Nuxt.js modules
   */
  modules: [
    // Doc: https://github.com/nuxt-community/dotenv-module
    '@nuxtjs/dotenv',
    '@nuxtjs/style-resources',
    '@nuxtjs/axios',
    '@nuxtjs/auth',
  ],
  router: {
    middleware: 'auth',
  },
  axios: {
    // https://axios.nuxtjs.org/
    baseURL: process.env.BACKEND_URL || 'http://localhost:8080/api',
    credentials: true,
  },
  auth: {
    // https://auth.nuxtjs.org/
    localStorage: true,
    cookie: {
      options: {
        maxAge: '86400',
        secure: true,
        sameSite: 'Strict',
      },
    },
    resetOnError: true,
    strategies: {
      local: {
        endpoints: {
          login: {
            url: '/login',
            method: 'post',
            propertyName: 'accessToken',
          },
          logout: {
            url: '/logout',
            method: 'post',
          },
          user: {
            url: '/user',
          },
        },
        tokenType: false,
        autoFetchUser: false,
      },
    },
  },
  styleResources: {
    scss: ['~/assets/sass/global.scss'],
  },
  /*
   ** Build configuration
   */
  build: {
    /*
     ** You can extend webpack config here
     */
    extend(config, ctx) {},
  },
};
