export const state = () => ({
  title: 'Workspace',
  loading: true,
  tasks: [],
  states: [],
  mergeStates: [],
  teamMembers: [],
  list: [],
  user: {
    id: '',
    user_name: '',
    email: '',
    address: '',
    rate: '',
    title: '',
  },
  userList: [],
  clients: [],
  currentTeam: null,
  currentClient: null,
  invoices: [],
  userTasks: [],
});

export const getters = {
  hasTasks: (state) => {
    return state.projects.length !== 0;
  },
  getTeamMembers: (state) => (id) => {
    console.log(
      state.teamMembers.filter((element) => {
        return element.id === id;
      }),
    );
    return state.teamMembers.filter((element) => {
      return element.id === id;
    });
  },
};

export const mutations = {
  setLoading(state, bool) {
    state.loading = bool;
  },
  setTasks(state, tasks) {
    state.tasks = tasks;
  },
  setStates(state, states) {
    state.states = states;
  },
  setMergeStates(state, mergeStates) {
    state.mergeStates = mergeStates;
  },
  setTeams(state, Teams) {
    state.list = Teams;
  },
  setCurrentTeam(state, team) {
    state.currentTeam = team;
  },
  setTeamMembers(state, members) {
    state.teamMembers = members;
  },
  setUser(state, user) {
    state.user = user;
  },
  setUsers(state, users) {
    state.userList = users;
  },
  setClients(state, clients) {
    state.clients = clients;
  },
  setCurrentClient(state, client) {
    state.currentClient = client;
  },
  setInvoices(state, invoices) {
    state.invoices = invoices;
  },
  setUserTasks(state, tasks) {
    state.userTasks = tasks;
  },
};

export const actions = {
  fetchInvoices({ commit }) {
    return new Promise((resolve, reject) => {
      this.$axios
        .get('/getInvoices')
        .then((res) => {
          commit('setInvoices', res.data);
          resolve();
        })
        .catch((error) => reject(error));
    });
  },
  fetchUserTasks({ commit }, id) {
    return new Promise((resolve, reject) => {
      this.$axios({
        method: 'GET',
        url: '/getUserTasks/' + id,
      })
        .then((res) => {
          commit('setUserTasks', res.data);
          resolve();
        })
        .catch((error) => {
          console.error(error);
          reject(error);
        });
    });
  },
  fetchTasks({ commit }) {
    return new Promise((resolve, reject) => {
      this.$axios
        .get('/tasks')
        .then((res) => {
          commit('setTasks', res.data);
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchStates({ commit }) {
    return new Promise((resolve, reject) => {
      this.$axios
        .get('/states')
        .then((res) => {
          commit('setStates', res.data);
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchMergeStates({ commit }, { id }) {
    commit('setLoading', true, { root: true });
    const params = {
      project_id: id,
    };
    return new Promise((resolve, reject) => {
      this.$axios
        .get('/mergeStates', { params })
        .then((res) => {
          commit('setMergeStates', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchAllTeams({ commit }) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios
        .get('/teams')
        .then((res) => {
          commit('setTeams', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchTeam({ commit }, id) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios({
        method: 'GET',
        url: '/team/' + id,
      })
        .then((res) => {
          commit('setCurrentTeam', res.data[0]);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchTeamMembers({ commit }) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios
        .get('/team/teamMembers')
        .then((res) => {
          commit('setTeamMembers', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchUser({ commit }) {
    return new Promise((resolve, reject) => {
      this.$axios
        .get('/user')
        .then((res) => {
          commit('setUser', res.data);
          resolve();
        })
        .catch((error) => {
          console.error(error);
          reject(error);
        });
    });
  },
  fetchAllUsers({ commit }) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios
        .get('/user/AllUsers')
        .then((res) => {
          commit('setUsers', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchAllClients({ commit }) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios
        .get('/clients')
        .then((res) => {
          commit('setClients', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchClient({ commit }, id) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios({
        method: 'GET',
        url: '/client/' + id,
      })
        .then((res) => {
          commit('setCurrentClient', res.data[0]);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  saveTeam({ commit }, data, id = null) {
    const method = id ? 'PUT' : 'POST';
    const url = id ? '/team/' + id : '/team';
    console.log(data);
    return new Promise((resolve, reject) => {
      this.$axios({
        method,
        url,
        data,
      })
        .then((response) => {
          return this.$router.push({
            path: '/teams/',
          });
        })
        .then(() => resolve())
        .catch((error) => {
          console.error(error);
          reject(error);
        });
    });
  },
  saveProfile({ commit }, data, id = null) {
    const method = id ? 'PUT' : 'POST';
    const url = id ? '/profile/' + id : '/profile';

    this.$axios({
      method,
      url,
      data,
    })
      .then((response) => {
        this.$router.push({
          path: '/profile/' + response.data,
        });
      })
      .catch((error) => console.error(error));
  },
  saveClient({ commit }, data, id = null) {
    const method = id ? 'PUT' : 'POST';
    const url = id ? '/client/' + id : '/client';

    return new Promise((resolve, reject) => {
      this.$axios({
        method,
        url,
        data,
      })
        .then((response) => {
          return this.$router.push({
            path: '/clients/',
          });
        })
        .then(() => resolve())
        .catch((error) => {
          console.error(error);
          reject(error);
        });
    });
  },
};
