export const state = () => ({
  list: [],
  user: [],
  currentProject: null,
});

export const getters = {};

export const mutations = {
  setProjects(state, projects) {
    state.list = projects;
  },
  setUserProjects(state, projects) {
    state.user = projects;
  },
  setCurrentProject(state, project) {
    state.currentProject = project;
  },
};

export const actions = {
  fetchAllProjects({ commit }) {
    commit('setLoading', true, { root: true });

    return new Promise((resolve, reject) => {
      this.$axios
        .get('/projects')
        .then((res) => {
          commit('setProjects', res.data);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          commit('setLoading', false, { root: true });
          reject(error);
        });
    });
  },
  fetchUserProjects({ commit }) {
    commit('setLoading', true, { root: true });
    this.$axios
      .get('/user/projects')
      .then((res) => {
        commit('setUserProjects', res.data);
        commit('setLoading', false, { root: true });
      })
      .catch((error) => console.error(error));
  },
  fetchProject({ commit }, id) {
    commit('setLoading', true, { root: true });
    return new Promise((resolve, reject) => {
      this.$axios({
        method: 'GET',
        url: '/project/' + id,
      })
        .then((res) => {
          commit('setCurrentProject', res.data[0]);
          commit('setLoading', false, { root: true });
          resolve();
        })
        .catch((error) => {
          console.error(error);
          reject(error);
        });
    });
  },
  saveProject({ commit }, data, id = null) {
    const method = id ? 'PUT' : 'POST';
    const url = id ? '/project/' + id : '/project';
    console.log(data);
    this.$axios({
      method,
      url,
      data,
    })
      .then((response) => {
        this.$router.push({
          path: '/projects/',
        });
      })
      .catch((error) => console.error(error));
  },
};
